# Copyright (C) 2019-2020 MicroSys Electronics GmbH
# Author: Kay Potthoff <kay.potthoff@microsys.de>

inherit patch

PATCHTOOL = "git"
PATCH_COMMIT_FUNCTIONS = "1"

DESCRIPTION = "tsntool is a tool to configure TSN funtionalities in user space"
SECTION = "base"

LICENSE = "GPLv2"
LIC_FILES_CHKSUM = "file://LICENSE;md5=ef58f855337069acd375717db0dbbb6d"

SRC_URI = "git://github.com/nxp-qoriq/tsntool;protocol=https;nobranch=1"
SRCREV = "d944afc021f06e99d1195eb05a5cead8f37177fa"

S = "${WORKDIR}/git"

DEPENDS += " virtual/kernel pkgconfig-native libnl libcjson readline "

PARALLEL_MAKE := "-j 1"

INSANE_SKIP:${PN} = "ldflags"

EXTRA_OEMAKE = "build tools"

do_configure[noexec] = "1"
do_patch[depends] += "virtual/kernel:do_shared_workdir"

python do_patch:prepend() {
    if d.getVar('PATCHTOOL') == 'git':
        srcsubdir = d.getVar('S')
        bb.process.run('git config am.threeWay true', cwd=srcsubdir)
        bb.process.run('git config am.keepcr true', cwd=srcsubdir)
        bb.process.run('git config apply.whitespace fix', cwd=srcsubdir)
        bb.process.run('git config apply.ignoreWhitespace change', cwd=srcsubdir)
}

do_patch_tsn_header() {

    mkdir -p ${S}/include/linux

    if [ ! -f ${S}/include/linux/tsn.h ]; then
        cp -a ${STAGING_KERNEL_DIR}/include/uapi/linux/tsn.h ${S}/include/linux
    fi
    if [ ! -f ${S}/include/linux/net_tstamp.h ]; then
        cp -a ${STAGING_KERNEL_DIR}/include/uapi/linux/net_tstamp.h ${S}/include/linux
    fi

}

python do_patch:append() {
    bb.build.exec_func("do_patch_tsn_header", d)
}

do_compile() {
    oe_runmake

    # oe_soinstall demands to have a version in the file name:
    mv libtsn.so libtsn.so.${PV}
}

do_install() {
    install -d ${D}/usr/bin
    install -d ${D}/usr/local/bin
    install -d ${D}/usr/lib
    install ${B}/tsntool ${D}/usr/bin
    install ${B}/tools/event ${D}/usr/local/bin
    install ${B}/tools/timestamping ${D}/usr/local/bin
    oe_soinstall ${B}/libtsn.so.${PV} ${D}/usr/lib
}

FILES:${PN} = " \
    /usr/bin/tsntool \
    /usr/local/bin/event \
    /usr/local/bin/timestamping \
    /usr/lib/libtsn.so* \
"

SRC_URI += "file://0001-Added-.gitignore.patch;name=patch0001"
SRC_URI += "file://0002-readinput-fixed-missing-format-argument.patch;name=patch0002"
SRC_URI += "file://0003-makefile-disabled-rpath-feature.patch;name=patch0003"
SRC_URI += "file://0004-makefile-added-option-soname.patch;name=patch0004"
SRC_URI += "file://0005-Added-meson.build.patch;name=patch0005"

SRC_URI[patch0001.md5sum] = "538e97db947992aa2cf3d3cfe510c9e4"
SRC_URI[patch0002.md5sum] = "8f9e8c558cbb0dde81203f98008d504e"
SRC_URI[patch0003.md5sum] = "84720a4268cf44124ebaea1a98124567"
SRC_URI[patch0004.md5sum] = "8d83bc35321c4364c93375186e0d4981"
SRC_URI[patch0005.md5sum] = "3e1bd74abd1625ed5fa1e229c9ab3af0"
